@@ -33,8 +33,8 @@ void init_mysql2_client();
 
 typedef struct {
   VALUE encoding;
-  short int active;
-  short int closed;
+  char active;
+  char closed;
   MYSQL *client;
 } mysql_client_wrapper;
 
