@@ -1,7 +1,7 @@
 # encoding: utf-8
 
-require 'eventmachine' unless defined? EventMachine
-require 'mysql2' unless defined? Mysql2
+require 'eventmachine'
+require 'mysql2'
 
 module Mysql2
   module EM
@@ -23,10 +23,14 @@ module Mysql2
       end
 
       def query(sql, opts={})
-        super(sql, opts.merge(:async => true))
-        deferable = ::EM::DefaultDeferrable.new
-        ::EM.watch(self.socket, Watcher, self, deferable).notify_readable = true
-        deferable
+        if ::EM.reactor_running?
+          super(sql, opts.merge(:async => true))
+          deferable = ::EM::DefaultDeferrable.new
+          ::EM.watch(self.socket, Watcher, self, deferable).notify_readable = true
+          deferable
+        else
+          super(sql, opts)
+        end
       end
     end
   end
